# su6-checker

[![PyPI - Version](https://img.shields.io/pypi/v/su6-checker.svg)](https://pypi.org/project/su6)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/su6-checker.svg)](https://pypi.org/project/su6)

-----
su6 (6 is pronounced as '/zɛs/' in Dutch, so 'su6' is basically 'success')  
This package will hopefully help achieve that!

**Table of Contents**

- [Installation](#installation)
- [Usage](#usage)
- [License](#license)

## Installation

```console
pip install su6-checker
```

## Usage
```console
su6 --help
# or, easiest to start:
su6 all
```

## License

`su6-checker` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
